@@ -13,7 +13,11 @@
 # limitations under the License.
 """Bert model and layer implementations.
 
-We should work to replace this with components from the keras-nlp library.
+These components come from the tensorflow official model repository for BERT:
+https://github.com/tensorflow/models/tree/master/official/nlp/modeling
+
+This is to get us into a testable state. We should work to replace all of these
+components with components from the keras-nlp library.
 """
 
 import tensorflow as tf
@@ -484,7 +488,7 @@ class BertModel(keras.Model):
 
         self._position_embedding_layer = keras_nlp.layers.PositionEmbedding(
             initializer=initializer,
-            max_length=max_sequence_length,
+            sequence_length=max_sequence_length,
             name="position_embedding",
         )
 
