@@ -13,6 +13,8 @@
 # limitations under the License.
 
 from keras_nlp import layers
+from keras_nlp import metrics
 from keras_nlp import tokenizers
+from keras_nlp import utils
 
-__version__ = "0.1.1"
+__version__ = "0.2.0"
